==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/logreader/l10n/de_DE.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Protokollierung",
    "Errors in the log" : "Fehler im Protokoll\n \n \n ",
    "Failed to get an iterator for log entries: %s" : "Es konnte kein Iterator für Protokolleinträge abgerufen werden: %s",
    "No errors in the logs since %s" : "Keine Fehler in den Protokollen seit %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n Fehler in den Protokollen seit %s","%n Fehler in den Protokollen seit %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n Warnungen in den Protokollen seit %s","%n Warnungen in den Protokollen seit %s"],
    "Log Reader" : "Protokoll-Anzeige",
    "A log reader for Nextcloud" : "Eine Protokoll-Anzeige für Nextcloud",
    "Log reader for Nextcloud" : "Protokoll-Anzeige für Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Wenn Sie der Meinung sind, dass dies ein Fehler ist, überprüfen Sie bitte {setting} in Ihrer {config} und lesen Sie das Nextcloud-Administrationshandbuch.",
    "Log reader" : "Protokoll-Anzeige",
    "Open log reader settings" : "Protokoll-Anzeigeeinstellungen öffnen",
    "Log reader settings" : "Protokoll-Anzeigeeinstellungen",
    "Currently the log file {file} is shown" : "Derzeit wird die Protokolldatei {file} angezeigt.",
    "Show server log" : "Serverprotokoll anzeigen",
    "Live view is disabled" : "Echtzeitanzeige ist deaktiviert",
    "No log file" : "Keine Protokolldatei",
    "File-based logging must be enabled to access logs from the Web UI." : "Für den Zugriff auf Protokolle über die Web-Benutzeroberfläche muss die dateibasierte Protokollierung aktiviert sein.",
    "Log entry successfully copied" : "Protokolleintrag kopiert",
    "Level" : "Stufe",
    "App" : "App",
    "No app in context" : "Keine App im Kontext",
    "Time" : "Zeit",
    "Copy raw entry" : "Roheintrag kopieren",
    "Copy formatted entry" : "Formatierten Eintrag kopieren",
    "Hide exception details" : "Ausnahmedetails ausblenden",
    "View exception details" : "Ausnahmedetails anzeigen",
    "Raw log entry" : "Roh-Protokoll Eintrag",
    "Search log entries" : "Protokolleinträge suchen",
    "Caused by {exception}" : "Verursacht von {exception}",
    "Line {line}" : "Zeile {line}",
    "Filter log levels" : "Protokollierungsstufen filtern",
    "Set log level" : "Protokollierungsstufe einstellen",
    "Time format" : "Zeitformat",
    "Live view" : "Echtzeitansicht",
    "Download/Upload logs" : "Protokolle herunter-/hochladen",
    "Ctrl" : "Strg",
    "Could not parse local log file" : "Lokale Protokolldatei konnte nicht verarbeitet werden",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Sie können auch Protokolleinträge anzeigen, die von Ihrer Zwischenablage kopiert wurden, indem Sie sie in der Protokollansicht einfügen mit: {keyboardShortcut}",
    "Download logs" : "Protokolldatei herunterladen",
    "Show local log file" : "Lokale Protokolldatei anzeigen",
    "Upload local log file to be displayed" : "Lokale Protokolldatei zur Anzeige hochladen",
    "Time format used for displaying the timestamp" : "Zeitformat, das zur Anzeige des Zeitstempels verwendet wird",
    "(Local log files only support the \"raw\" time format)" : "(Lokale Protokolldateien unterstützen nur das \"rohe\" Zeitformat)",
    "Could not change date time format." : "Das Datum-Uhrzeit-Format konnte nicht geändert werden.",
    "Raw data" : "Rohdaten",
    "Local time" : "Lokale Zeit",
    "UTC time" : "UTC-Zeit",
    "Relative" : "Relativ",
    "Could not change live view setting." : "Einstellungen der Echtzeitansicht konnten nicht geändert werden.",
    "Polling is disabled because server is not configured to log to file" : "Die Abfrage ist deaktiviert, da der Server nicht für die Protokollierung in eine Datei konfiguriert ist",
    "Polling (live view)" : "Abfrage (Echtzeitansicht)",
    "Could not set logging levels to show" : "Anzuzeigende Protokollierungsebenen konnten nicht eingestellt werden",
    "Filter logging levels" : "Protokollierungsebenen filtern",
    "Could not set logging level" : "Die Protokollierungsstufe konnte nicht festgelegt werden",
    "Set backend loglevel" : "Backend-Protokollierungsstufe festlegen",
    "Application" : "Anwendung",
    "Message" : "Nachricht",
    "Log entry actions" : "Eingabeaktionen protokollieren",
    "Loading older log entries" : "Ältere Protokolleinträge laden",
    "No older log entries available" : "Keine älteren Protokolleinträge vorhanden",
    "Collapse row" : "Zeile zuklappen",
    "Expand row" : "Zeile aufklappen",
    "Show details" : "Details anzeigen",
    "Debug" : "Fehlersuche",
    "Info" : "Info",
    "Warning" : "Warnung",
    "Error" : "Fehler",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Protokolleinträge konnten nicht geladen werden",
    "Clipboard" : "Zwischenablage",
    "Could not parse clipboard content" : "Inhalt der Zwischenablage konnte nicht analysiert werden",
    "Could not fetch new log entries (server unavailable)" : "Neue Protokolleinträge konnten nicht abgerufen werden (Server nicht verfügbar)",
    "Could not fetch new entries" : "Neue Einträge konnten nicht abgerufen werden",
    "Could not copy to clipboard, please copy manually:" : "Konnte nicht in die Zwischenablage kopieren, bitte manuell kopieren:",
    "\tfrom {address} by {user} at {time}\n" : "\tvon {address} von {user} um {time}\n"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/logreader/l10n/de_DE.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Protokollierung",
    "Errors in the log" : "Fehler im Protokoll\n \n \n ",
    "Failed to get an iterator for log entries: %s" : "Es konnte kein Iterator für Protokolleinträge abgerufen werden: %s",
    "No errors in the logs since %s" : "Keine Fehler in den Protokollen seit %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n Fehler in den Protokollen seit %s","%n Fehler in den Protokollen seit %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n Warnungen in den Protokollen seit %s","%n Warnungen in den Protokollen seit %s"],
    "Log Reader" : "Protokoll-Anzeige",
    "A log reader for Nextcloud" : "Eine Protokoll-Anzeige für Nextcloud",
    "Log reader for Nextcloud" : "Protokoll-Anzeige für Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Wenn Sie der Meinung sind, dass dies ein Fehler ist, überprüfen Sie bitte {setting} in Ihrer {config} und lesen Sie das Nextcloud-Administrationshandbuch.",
    "Log reader" : "Protokoll-Anzeige",
    "Open log reader settings" : "Protokoll-Anzeigeeinstellungen öffnen",
    "Log reader settings" : "Protokoll-Anzeigeeinstellungen",
    "Currently the log file {file} is shown" : "Derzeit wird die Protokolldatei {file} angezeigt.",
    "Show server log" : "Serverprotokoll anzeigen",
    "Live view is disabled" : "Echtzeitanzeige ist deaktiviert",
    "No log file" : "Keine Protokolldatei",
    "File-based logging must be enabled to access logs from the Web UI." : "Für den Zugriff auf Protokolle über die Web-Benutzeroberfläche muss die dateibasierte Protokollierung aktiviert sein.",
    "Log entry successfully copied" : "Protokolleintrag kopiert",
    "Level" : "Stufe",
    "App" : "App",
    "No app in context" : "Keine App im Kontext",
    "Time" : "Zeit",
    "Copy raw entry" : "Roheintrag kopieren",
    "Copy formatted entry" : "Formatierten Eintrag kopieren",
    "Hide exception details" : "Ausnahmedetails ausblenden",
    "View exception details" : "Ausnahmedetails anzeigen",
    "Raw log entry" : "Roh-Protokoll Eintrag",
    "Search log entries" : "Protokolleinträge suchen",
    "Caused by {exception}" : "Verursacht von {exception}",
    "Line {line}" : "Zeile {line}",
    "Filter log levels" : "Protokollierungsstufen filtern",
    "Set log level" : "Protokollierungsstufe einstellen",
    "Time format" : "Zeitformat",
    "Live view" : "Echtzeitansicht",
    "Download/Upload logs" : "Protokolle herunter-/hochladen",
    "Ctrl" : "Strg",
    "Could not parse local log file" : "Lokale Protokolldatei konnte nicht verarbeitet werden",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Es können auch Protokolleinträge angezeigt werden, die von Ihrer Zwischenablage kopiert wurden, indem Sie sie in der Protokollansicht einfügen mit: {keyboardShortcut}",
    "Download logs" : "Protokolldatei herunterladen",
    "Show local log file" : "Lokale Protokolldatei anzeigen",
    "Upload local log file to be displayed" : "Lokale Protokolldatei zur Anzeige hochladen",
    "Time format used for displaying the timestamp" : "Zeitformat, das zur Anzeige des Zeitstempels verwendet wird",
    "(Local log files only support the \"raw\" time format)" : "(Lokale Protokolldateien unterstützen nur das \"rohe\" Zeitformat)",
    "Could not change date time format." : "Das Datum-Uhrzeit-Format konnte nicht geändert werden.",
    "Raw data" : "Rohdaten",
    "Local time" : "Lokale Zeit",
    "UTC time" : "UTC-Zeit",
    "Relative" : "Relativ",
    "Could not change live view setting." : "Einstellungen der Echtzeitansicht konnten nicht geändert werden.",
    "Polling is disabled because server is not configured to log to file" : "Die Abfrage ist deaktiviert, da der Server nicht für die Protokollierung in eine Datei konfiguriert ist",
    "Polling (live view)" : "Abfrage (Echtzeitansicht)",
    "Could not set logging levels to show" : "Anzuzeigende Protokollierungsebenen konnten nicht eingestellt werden",
    "Filter logging levels" : "Protokollierungsebenen filtern",
    "Could not set logging level" : "Die Protokollierungsstufe konnte nicht festgelegt werden",
    "Set backend loglevel" : "Backend-Protokollierungsstufe festlegen",
    "Application" : "Anwendung",
    "Message" : "Nachricht",
    "Log entry actions" : "Eingabeaktionen protokollieren",
    "Loading older log entries" : "Ältere Protokolleinträge laden",
    "No older log entries available" : "Keine älteren Protokolleinträge vorhanden",
    "Collapse row" : "Zeile zuklappen",
    "Expand row" : "Zeile aufklappen",
    "Show details" : "Details anzeigen",
    "Debug" : "Fehlersuche",
    "Info" : "Info",
    "Warning" : "Warnung",
    "Error" : "Fehler",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Protokolleinträge konnten nicht geladen werden",
    "Clipboard" : "Zwischenablage",
    "Could not parse clipboard content" : "Inhalt der Zwischenablage konnte nicht analysiert werden",
    "Could not fetch new log entries (server unavailable)" : "Neue Protokolleinträge konnten nicht abgerufen werden (Server nicht verfügbar)",
    "Could not fetch new entries" : "Neue Einträge konnten nicht abgerufen werden",
    "Could not copy to clipboard, please copy manually:" : "Konnte nicht in die Zwischenablage kopieren, bitte manuell kopieren:",
    "\tfrom {address} by {user} at {time}\n" : "\tvon {address} von {user} um {time}\n"
},
"nplurals=2; plural=(n != 1);");
